@@ -1,17 +1,17 @@
 #' @title Predict the elapsed runtime of the next call to `make()`.
 #' @description This function simply sums the elapsed build times
-#' from \code{\link{rate_limiting_times}()}, and this
+#' from [rate_limiting_times()], and this
 #' feature is experimental.
 #' To date, the accuracy/precision of the results
 #' has not yet been confirmed by performance studies.
 #' @details For the results to make sense, the previous build times
 #' of all targets need to be available (automatically cached
-#' by \code{\link{make}()}). Otherwise, \code{predict_runtime()}
+#' by [make()]). Otherwise, `predict_runtime()`
 #' will warn you and tell you which targets have missing times.
 #' @export
-#' @seealso \code{\link{rate_limiting_times}},
-#' \code{\link{build_times}}
-#' \code{\link{make}}
+#' @seealso [rate_limiting_times()],
+#'   [build_times()]
+#'   [make()]
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
@@ -31,29 +31,29 @@
 #' )
 #' })
 #' }
-#' @return A \code{lubridate} \code{Duration} object
-#' with the predicted runtime of the next \code{\link{make}()}.
+#' @return A `lubridate` `Duration` object
+#'   with the predicted runtime of the next [make()].
 #' @param config option internal runtime parameter list of
-#' \code{\link{make}(...)},
-#' produced by both \code{\link{make}()} and
-#' \code{\link{drake_config}()}.
+#'   \code{\link{make}(...)},
+#'   produced by both [make()] and
+#'   [drake_config()].
 #' @param targets Character vector, names of targets.
-#' Predict the runtime of building these targets
-#' plus dependencies.
-#' Defaults to all targets.
+#'   Predict the runtime of building these targets
+#'   plus dependencies.
+#'   Defaults to all targets.
 #' @param from_scratch logical, whether to predict a
-#' \code{\link{make}()} build from scratch or to
-#' take into account the fact that some targets may be
-#' already up to date and therefore skipped.
+#'   [make()] build from scratch or to
+#'   take into account the fact that some targets may be
+#'   already up to date and therefore skipped.
 #' @param targets_only logical, whether to factor in
-#' just the targets into the calculations or use the
-#' build times for everything, including the imports
+#'   just the targets into the calculations or use the
+#'   build times for everything, including the imports
 #' @param future_jobs hypothetical number of jobs
-#' assumed for the predicted runtime.
-#' assuming this number of jobs.
+#'   assumed for the predicted runtime.
+#'   assuming this number of jobs.
 #' @param digits number of digits for rounding the time
 predict_runtime <- function(
-  config,
+  config = drake::read_drake_config(),
   targets = NULL,
   future_jobs = 1,
   from_scratch = FALSE,
@@ -75,11 +75,11 @@ predict_runtime <- function(
 }
 
 #' @title Return a data frame of elapsed build times of
-#' the rate-limiting targets of a drake project.
+#'   the rate-limiting targets of a drake project.
 #'
 #' @description This function produces a conservative
-#' estimate for \code{\link{predict_runtime}()}
-#' for when parallel computing is used in \code{\link{make}()}.
+#' estimate for [predict_runtime()]
+#' for when parallel computing is used in [make()].
 #' This feature is experimental.
 #' The accuracy, precision, and utility of these supposedly
 #' rate-limiting times has not been confirmed by rigorous
@@ -87,29 +87,29 @@ predict_runtime <- function(
 #'
 #' @export
 #'
-#' @details The \code{stage} column of the returned data frame
+#' @details The `stage` column of the returned data frame
 #' is an index that denotes a parallelizable stage.
-#' Within each stage during \code{\link{make}()},
+#' Within each stage during [make()],
 #' the targets are divided among the available jobs.
-#' For \code{rate_limiting_times()},
+#' For `rate_limiting_times()`,
 #' we assume the targets are divided evenly among the jobs
 #' and one job gets all the slowest targets.
 #' The build times of this hypothetical pessimistic job
 #' are returned for each stage. \cr
 #'
-#' By default \code{from_scratch} is \code{FALSE}. That way,
-#' \code{rate_limiting_times()} takes into account that some
+#' By default `from_scratch` is `FALSE`. That way,
+#' `rate_limiting_times()` takes into account that some
 #' targets are already up to date, meaning their elapsed
-#' build times will be instant during the next \code{\link{make}()}.
+#' build times will be instant during the next [make()].
 #'
 #' For the results to make sense, the previous build times
 #' of all targets need to be available (automatically cached
-#' by \code{\link{make}()}). Otherwise, \code{rate_limiting_times()}
+#' by [make()]). Otherwise, `rate_limiting_times()`
 #' will warn you and tell you which targets have missing times.
 #'
-#' @seealso \code{\link{predict_runtime}},
-#' \code{\link{build_times}}
-#' \code{\link{make}}
+#' @seealso [predict_runtime()],
+#'   [build_times()]
+#'   [make()]
 #'
 #' @examples
 #' \dontrun{
@@ -138,32 +138,32 @@ predict_runtime <- function(
 #' }
 #'
 #' @return A data frame of times of the worst-case scenario
-#' rate-limiting targets in each parallelizable stage.
+#'   rate-limiting targets in each parallelizable stage.
 #'
 #' @param config option internal runtime parameter list of
-#' \code{\link{make}(...)},
-#' produced by both \code{\link{make}()} and
-#' \code{\link{drake_config}()}.
+#'   \code{\link{make}(...)},
+#'   produced by both [make()] and
+#'   [drake_config()].
 #'
 #' @param targets Character vector, names of targets.
-#' Find the rate-limiting times for building these targets
-#' plus dependencies.
-#' Defaults to all targets.
+#'   Find the rate-limiting times for building these targets
+#'   plus dependencies.
+#'   Defaults to all targets.
 #'
 #' @param from_scratch logical, whether to assume
-#' next hypothetical call to \code{\link{make}()}
-#' is a build from scratch (after \code{\link{clean}()}).
+#'   next hypothetical call to [make()]
+#'   is a build from scratch (after [clean()]).
 #'
 #' @param targets_only logical, whether to factor in just the
-#' targets or use times from everything, including the imports.
+#'   targets or use times from everything, including the imports.
 #'
 #' @param future_jobs hypothetical number of jobs
-#' assumed for the predicted runtime.
-#' assuming this number of jobs.
+#'   assumed for the predicted runtime.
+#'   assuming this number of jobs.
 #'
 #' @param digits number of digits for rounding the times.
 rate_limiting_times <- function(
-  config,
+  config = drake::read_drake_config(),
   targets = NULL,
   from_scratch = FALSE,
   targets_only = FALSE,
@@ -183,8 +183,9 @@ rate_limiting_times <- function(
     cache = config$cache,
     digits = Inf,
     targets_only = FALSE,
-    verbose = TRUE
-  )
+    verbose = config$verbose
+  ) %>%
+    as.data.frame
   keys <- V(config$graph)$name
   import_keys <- setdiff(keys, config$plan$target)
   items <- intersect(keys, times$item)
@@ -213,7 +214,11 @@ rate_limiting_times <- function(
   ) %>%
     round_times(digits = digits) %>%
     unname_rows
-  out[!is.na(out$item), ]
+  out <- out[!is.na(out$item), ]
+  tryCatch(
+    as_tibble(out),
+    error = error_tibble_times
+  )
 }
 
 append_stages_to_times <- function(x, config){
