@@ -1,6 +1,6 @@
 #' @title Write dummy timestamp files for
-#' \code{\link{make}(..., parallelism = "Makefile")}.
-#' @description For \code{"Makefile"} parallelism,
+#'   \code{\link{make}(..., parallelism = "Makefile")}.
+#' @description For `"Makefile"` parallelism,
 #' dummy timestamp files tell the Makefile
 #' which targets need to be built and which can be skipped.
 #' This function is for internal use only. It is only exported
@@ -9,7 +9,7 @@
 #' @keywords internal
 #' @return nothing
 #' @param config Internal master configuration list
-#' produced by \code{\link{drake_config}}.
+#'   produced by [drake_config()].
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
@@ -25,7 +25,9 @@ time_stamps <- function(config){
   dir_empty(stamp_dir)
   write_time_stamp_template(cache_path)
   build_these <- next_stage(config = config)
-  set_attempt_flag(flag = length(build_these), config = config)
+  if (length(build_these)){
+    set_attempt_flag(config = config)
+  }
   stamp_these <- setdiff(config$plan$target, build_these)
   lightly_parallelize(
     stamp_these, write_time_stamp, jobs = config$jobs, config = config)
