@@ -10,7 +10,7 @@
     warning(
       "Auto-saved workspace file '.RData' detected. ",
       "This is bad for reproducible code. ",
-      "You can remove it with unlink('.RData').",
+      "You can remove it with unlink(\".RData\").",
       call. = FALSE
     )
   }
