@@ -5,8 +5,12 @@
 library(future.batchtools)
 library(drake)
 
-# Use backend(multicore) instead for a dry run.
-backend(batchtools_sge(template = "sge-simple.tmpl"))
+# Use future::plan(multicore) instead for a dry run.
+future::plan(
+  batchtools_sge,
+  template = "sge-simple.tmpl",
+  workers = 4
+)
 
 load_basic_example()
 make(
