@@ -4,8 +4,8 @@ drake_context("strings")
 # https://github.com/ropensci/eply
 
 test_with_dir("Functions drake_quotes() and drake_unquote() are correct.", {
-  expect_equal(drake_quotes(), "\"\"")
-  expect_equal(drake_quotes(single = T), "\'\'")
+  expect_equal(drake_quotes(), character(0))
+  expect_equal(drake_quotes(single = T), character(0))
   expect_equal(drake_quotes(drake_strings(x, y)), c("\"x\"", "\"y\""))
   expect_equal(drake_quotes(c("x", "y")), c("\"x\"", "\"y\""))
   expect_equal(drake_quotes(c("x", "y"), single = F), c("\"x\"", "\"y\""))
@@ -13,34 +13,17 @@ test_with_dir("Functions drake_quotes() and drake_unquote() are correct.", {
 
   expect_equal(drake_unquote(), character(0))
   expect_equal(drake_unquote(drake_strings(x, y)), drake_strings(x, y))
-  expect_equal(drake_unquote(
-    deep = TRUE,
-    x = drake_quotes(
-      drake_quotes(
-        drake_quotes(c("x", "y")), single = T),
-        single = F
-      )
-    ),
-    c("x", "y")
-  )
 
   a <- c(
-    "\"x\"", "\"y\"", "return(a)",
-    "return(\"a\")", "\"x", "y\"",
+    "\"x\"", "\"y\"", "'z'", "return(a)",
+    "return(\"a\")",
     "\"x\"", "\"return(\"a\")\"")
   b <- c(
-    "x", "y", "return(a)",
-    "return(\"a\")", "x", "y",
+    "x", "y", "z", "return(a)",
+    "return(\"a\")",
     "x", "return(\"a\")"
   )
   expect_equal(drake_unquote(a), b)
-
-  x <- c("'x'", '"y"', "\"'x'\"", "'\"y\"'")
-  y <- c("x", "y", "'x'", "\"y\"")
-  z <- c("x", "y", "x", "y")
-  expect_equal(drake_unquote(x), y)
-  expect_equal(drake_unquote(x, deep = F), y)
-  expect_equal(drake_unquote(x, deep = T), z)
 })
 
 test_with_dir("Function drake_strings() is correct.", {
